@@ -23,6 +23,8 @@
 #include "empathy-event-manager.h"
 
 #include <glib/gi18n.h>
+#include <tp-account-widgets/tpaw-images.h>
+#include <tp-account-widgets/tpaw-utils.h>
 
 #include "empathy-call-utils.h"
 #include "empathy-connection-aggregator.h"
@@ -915,8 +917,19 @@ approve_call_channel (EmpathyEventManager *self,
 
   priv->ringing++;
   if (priv->ringing == 1)
-    empathy_sound_manager_start_playing (priv->sound_mgr, NULL,
-        EMPATHY_SOUND_PHONE_INCOMING, MS_BETWEEN_RING);
+    {
+      TpAccountManager *am = tp_account_manager_dup ();
+      TpConnectionPresenceType presence;
+
+      presence = tp_account_manager_get_most_available_presence (am,
+          NULL, NULL);
+
+      if (presence != TP_CONNECTION_PRESENCE_TYPE_BUSY)
+        empathy_sound_manager_start_playing (priv->sound_mgr, NULL,
+            EMPATHY_SOUND_PHONE_INCOMING, MS_BETWEEN_RING);
+
+      g_object_unref (am);
+    }
 }
 
 static void
@@ -1098,7 +1111,7 @@ check_publish_state (EmpathyEventManager *self,
 
   message = tp_contact_get_publish_request (tp_contact);
 
-  if (!EMP_STR_EMPTY (message))
+  if (!TPAW_STR_EMPTY (message))
     event_msg = g_strdup_printf (_("\nMessage: %s"), message);
   else
     event_msg = NULL;
@@ -1123,10 +1136,10 @@ event_manager_publish_state_changed_cb (TpContact *contact,
 }
 
 static void
-event_manager_presence_changed_cb (EmpathyContact *contact,
+check_presence (EmpathyEventManager *manager,
+    EmpathyContact *contact,
     TpConnectionPresenceType current,
-    TpConnectionPresenceType previous,
-    EmpathyEventManager *manager)
+    TpConnectionPresenceType previous)
 {
   EmpathyEventManagerPriv *priv = GET_PRIV (manager);
   TpAccount *account;
@@ -1154,7 +1167,7 @@ event_manager_presence_changed_cb (EmpathyContact *contact,
             {
               event_manager_add (manager, NULL, contact,
                   EMPATHY_EVENT_TYPE_PRESENCE_OFFLINE,
-                  EMPATHY_IMAGE_AVATAR_DEFAULT,
+                  TPAW_IMAGE_AVATAR_DEFAULT,
                   empathy_contact_get_alias (contact), _("Disconnected"),
                   NULL, NULL, NULL);
             }
@@ -1175,7 +1188,7 @@ event_manager_presence_changed_cb (EmpathyContact *contact,
             {
               event_manager_add (manager, NULL, contact,
                   EMPATHY_EVENT_TYPE_PRESENCE_ONLINE,
-                  EMPATHY_IMAGE_AVATAR_DEFAULT,
+                  TPAW_IMAGE_AVATAR_DEFAULT,
                   empathy_contact_get_alias (contact), _("Connected"),
                   NULL, NULL, NULL);
             }
@@ -1186,6 +1199,15 @@ out:
   g_object_unref (presence_mgr);
 }
 
+static void
+event_manager_presence_changed_cb (EmpathyContact *contact,
+    TpConnectionPresenceType current,
+    TpConnectionPresenceType previous,
+    EmpathyEventManager *manager)
+{
+  check_presence (manager, contact, current, previous);
+}
+
 static GObject *
 event_manager_constructor (GType type,
 			   guint n_props,
@@ -1288,6 +1310,10 @@ contact_list_changed_cb (EmpathyConnectionAggregator *aggregator,
       tp_g_signal_connect_object (contact, "presence-changed",
           G_CALLBACK (event_manager_presence_changed_cb), self, 0);
 
+      check_presence (self, contact,
+          empathy_contact_get_presence (contact),
+          TP_CONNECTION_PRESENCE_TYPE_OFFLINE);
+
       tp_g_signal_connect_object (tp_contact, "notify::publish-state",
           G_CALLBACK (event_manager_publish_state_changed_cb), self, 0);
 
@@ -1350,7 +1376,7 @@ empathy_event_manager_init (EmpathyEventManager *manager)
   g_ptr_array_unref (contacts);
   g_ptr_array_unref (empty);
 
-   am = tp_account_manager_dup ();
+  am = tp_account_manager_dup ();
 
   priv->approver = tp_simple_approver_new_with_am (am, "Empathy.EventManager",
       FALSE, approve_channels, manager, NULL);
