@@ -330,6 +330,14 @@ roster_window_load_events_idle_cb (gpointer user_data)
   return FALSE;
 }
 
+static void
+hide_search_bar (EmpathyRosterWindow *roster_window)
+{
+  if (TPAW_IS_LIVE_SEARCH (roster_window->priv->search_bar) &&
+      gtk_widget_is_visible (roster_window->priv->search_bar))
+    gtk_widget_hide (roster_window->priv->search_bar);
+}
+
 static void
 individual_activated_cb (EmpathyRosterView *self,
     FolksIndividual *individual,
@@ -348,6 +356,9 @@ individual_activated_cb (EmpathyRosterView *self,
   empathy_chat_with_contact (contact, gtk_get_current_event_time ());
 
   g_object_unref (contact);
+
+  /* Hide the search-bar upon hitting "Enter" on an individual */
+  hide_search_bar (EMPATHY_ROSTER_WINDOW (user_data));
 }
 
 static void
@@ -357,6 +368,9 @@ event_activated_cb (EmpathyRosterView *self,
     gpointer user_data)
 {
   empathy_event_activate (event);
+
+  /* Hide the search-bar upon an event activation */
+  hide_search_bar (EMPATHY_ROSTER_WINDOW (user_data));
 }
 
 static void
@@ -730,7 +744,7 @@ roster_window_error_display (EmpathyRosterWindow *self,
        tp_account_get_detailed_error (account, NULL)))
     {
       roster_window_error_add_stock_button (GTK_INFO_BAR (info_bar),
-          GTK_STOCK_REFRESH, _("Update software..."),
+          GTK_STOCK_REFRESH, _("Update software…"),
           ERROR_RESPONSE_RETRY);
     }
   else
@@ -1948,6 +1962,15 @@ menu_deactivate_cb (GtkMenuShell *menushell,
   gtk_menu_detach (GTK_MENU (menushell));
 }
 
+static void
+menu_item_activated_cb (GtkMenuShell *menushell,
+    gpointer user_data)
+{
+    EmpathyRosterWindow *roster_window = EMPATHY_ROSTER_WINDOW (user_data);
+
+    hide_search_bar (roster_window);
+}
+
 static void
 popup_individual_menu_cb (EmpathyRosterView *view,
     const gchar *active_group,
@@ -1978,6 +2001,8 @@ popup_individual_menu_cb (EmpathyRosterView *view,
    * during the whole lifetime of Empathy. */
   g_signal_connect (menu, "deactivate", G_CALLBACK (menu_deactivate_cb),
       NULL);
+  g_signal_connect (menu, "menu-item-activated",
+      G_CALLBACK (menu_item_activated_cb), user_data);
 
   gtk_menu_attach_to_widget (GTK_MENU (menu), GTK_WIDGET (view), NULL);
   gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL, button, time);
